@@ -10,8 +10,8 @@ package EB::Booking::Decode;
 # Author          : Johan Vromans
 # Created On      : Tue Sep 20 15:16:31 2005
 # Last Modified By: Johan Vromans
-# Last Modified On: Tue May 29 14:38:52 2012
-# Update Count    : 182
+# Last Modified On: Tue Oct 13 16:58:45 2015
+# Update Count    : 194
 # Status          : Unknown, Use with caution!
 
 ################ Common stuff ################
@@ -57,6 +57,7 @@ sub decode {
     my $rr = $dbh->do("SELECT bsk_id, bsk_nr, bsk_ref, bsk_desc, ".
 		      "bsk_dbk_id, bsk_date, bsk_amount, bsk_saldo, bsk_isaldo, bsk_bky ".
 		      ($dbver lt "001000002" ? ", bsk_paid" : ", bsk_open").
+		      ",bsk_att".
 		      " FROM Boekstukken".
 		      " WHERE bsk_id = ?", $bsk);
 
@@ -66,7 +67,8 @@ sub decode {
     }
 
     my ($bsk_id, $bsk_nr, $bsk_ref, $bsk_desc, $bsk_dbk_id,
-	$bsk_date, $bsk_amount, $bsk_saldo, $bsk_isaldo, $bsk_bky, $bsk_open) = @$rr;
+	$bsk_date, $bsk_amount, $bsk_saldo, $bsk_isaldo, $bsk_bky,
+	$bsk_open, $bsk_att) = @$rr;
 
     my $tot = 0;
     my ($dbktype, $acct, $dbk_desc) = @{$dbh->do("SELECT dbk_type, dbk_acc_id, dbk_desc".
@@ -95,12 +97,20 @@ sub decode {
 	    }
 	    $cmd .= " --".__xt("cmo:boeking:beginsaldo")."=" . numfmt_plain($bsk_isaldo) if $ex_tot && defined $bsk_isaldo;
 	    $cmd .= " --".__xt("cmo:boeking:saldo")."=" . numfmt_plain($bsk_saldo) if $ex_tot && defined $bsk_saldo;
+	    if ( $bsk_att ) {
+		my ( $name, $enc, $contents ) = @{ $dbh->do("SELECT att_name, att_encoding".
+							   " FROM Attachments".
+							   " WHERE att_id = ?", $bsk_att) };
+		$name = sprintf("int://%08d/%s", $bsk_att, $name)
+		  unless $enc == ATTENCODING_URI;
+		$cmd .= " --bijlage=" . _quote($name);
+	    }
 	}
 	else {
 	    $cmd = "Boekstuk $bsk_id, nr $bsk_nr, dagboek " .
 	      $dbh->lookup($bsk_dbk_id, qw(Dagboeken dbk_id dbk_desc =)).
 		"($bsk_dbk_id)".
-		  ", ".datefmt_full(datum $bsk_date).
+		  ", datum ".datefmt_full($bsk_date).
 		    ", ";
 	    if ( $dbktype == DBKTYPE_INKOOP || $dbktype == DBKTYPE_VERKOOP ) {
 		my ($rd, $rt) = @{$dbh->do("SELECT rel_desc,rel_debcrd".
@@ -222,7 +232,11 @@ sub decode {
 		|| $dbktype == DBKTYPE_MEMORIAAL ) {
 	    $bsr_amount = -$bsr_amount;
 	    my $dd = "";
-	    $dd = " ".datefmt_full($bsr_date) unless $bsr_date eq $bsk_date;
+	    # Explicitly add the date if it is different, or when the
+	    # description could be parsed as a date (bug #40).
+	    $dd = " ".datefmt_full($bsr_date)
+	      if $bsr_date ne $bsk_date || $bsr_desc =~ /^[[:digit:]]+-/;
+
 	    if ( $bsr_type == 0 ) {
 		$cmd .= $single ? " " : " \\\n\t";
 		$cmd .= "std$dd " . _quote($bsr_desc) . " " .
