@@ -5,8 +5,8 @@ use utf8;
 # Author          : Johan Vromans
 # Created On      : Tue Aug 30 09:49:11 2005
 # Last Modified By: Johan Vromans
-# Last Modified On: Fri Aug 31 18:18:52 2012
-# Update Count    : 308
+# Last Modified On: Thu Mar 13 17:55:41 2014
+# Update Count    : 313
 # Status          : Unknown, Use with caution!
 
 package main;
@@ -209,7 +209,7 @@ sub set_relatie {
     return __x("Ongeldig bedrag: {amount}", amount => $amt)."\n" unless defined($anew = amount($amt));
 
     $self->check_open(0);
-    push(@{$self->{o}->{relatie}}, [$bky, $nr, $date, $desc, $type, $code, $acct, $anew]);
+    push(@{$self->{o}->{relatie}}, [$bky, $nr, $date, $desc, $type, $code, $dbk, $acct, $anew]);
     "";
 }
 
@@ -330,7 +330,7 @@ sub open {
 
 	    # Process relations.
 	    foreach my $r ( @{$o->{relatie}} ) {
-		my ($bky, $nr, $date, $desc, $debcrd, $code, $acct, $amt) = @$r;
+		my ($bky, $nr, $date, $desc, $debcrd, $code, $dbk, $acct, $amt) = @$r;
 
 		if ( $debcrd ) {
 		    $adeb = $acct;
@@ -456,13 +456,13 @@ sub open {
 	my $dbk_inkoop;
 	my $dbk_verkoop;
 	foreach my $r ( @{$o->{relatie}} ) {
-	    my ($bky, $nr, $date, $desc, $debcrd, $code, $acct, $amt) = @$r;
+	    my ($bky, $nr, $date, $desc, $debcrd, $code, $dagboek, $acct, $amt) = @$r;
 	    $nr = $dbh->get_sequence("bsk_nr_0_seq") unless defined $nr;
 
-	    my ($dagboek) = @{$dbh->do("SELECT dbk_id".
-				       " FROM Dagboeken".
-				       " WHERE dbk_acc_id = ?",
-				       $acct)};
+#	    my ($dagboek) = @{$dbh->do("SELECT dbk_id".
+#				       " FROM Dagboeken".
+#				       " WHERE dbk_acc_id = ?",
+#				       $acct)};
 
 	    if ( $debcrd ) {
 #		unless ( $dbk_verkoop ) {
@@ -592,45 +592,63 @@ dan ook in één enkele EekBoek shell sessie worden afgehandeld.
 Mogelijke opdrachten voor openen van een boekjaar:
 
   adm_btwperiode [ jaar | kwartaal | maand ]
+
   adm_boekjaarcode <code>
-		Een code van max 4 letters en/of cijfers waarmee het
-		boekjaar kan worden geïdentificeerd.
-		Standaard wordt het jaartal van het boekjaar genomen.
+
+Een code van max 4 letters en/of cijfers waarmee het
+boekjaar kan worden geïdentificeerd.
+Standaard wordt het jaartal van het boekjaar genomen.
+
   adm_open
-		Alle informatie die met de bovenstaande opdrachten is
-		ingevoerd, wordt verwerkt.
+
+Alle informatie die met de bovenstaande opdrachten is
+ingevoerd, wordt verwerkt.
 
 Opdrachten voor het openen van een administratie:
 
   adm_naam "Naam van de administratie"
+
   adm_btwperiode [ jaar | kwartaal | maand ]
+
   adm_begindatum <jaar>
-		Een administratie loopt altijd van 1 januari tot en
-		met 31 december van een kalenderjaar.
+
+Een administratie loopt altijd van 1 januari tot en
+met 31 december van een kalenderjaar.
+
   adm_boekjaarcode <code>
-		Een code van max 4 letters en/of cijfers waarmee het
-		boekjaar kan worden geïdentificeerd.
-		Standaard wordt het jaartal van het boekjaar genomen.
-		De boekjaarcode is alleen relevant indien er meerdere
-		boekjaren in één administratie worden bijgehouden.
+
+Een code van max 4 letters en/of cijfers waarmee het
+boekjaar kan worden geïdentificeerd.
+
+Standaard wordt het jaartal van het boekjaar genomen.
+De boekjaarcode is alleen relevant indien er meerdere
+boekjaren in één administratie worden bijgehouden.
+
   adm_balanstotaal <bedrag>
-		Als een balanstotaal is opgegeven, moeten er ook
-		openingsbalansboekingen worden uitgevoerd met een of
-		meer adm_balans opdrachten.
+
+Als een balanstotaal is opgegeven, moeten er ook
+openingsbalansboekingen worden uitgevoerd met een of
+meer adm_balans opdrachten.
+
   adm_balans <balansrekening> <bedrag>
-		De debet en credit boekingen moeten uiteindelijk
-		allebei gelijk zijn aan het opgegeven balanstotaal.
-		Indien er een bedrag is opgegeven voor de balansrekening
-		Crediteuren of Debiteuren, dan moet er voor dit bedrag
-		ook openstaande posten worden ingevoerd met een of
-		meer adm_relatie opdrachten.
+
+De debet en credit boekingen moeten uiteindelijk
+allebei gelijk zijn aan het opgegeven balanstotaal.
+Indien er een bedrag is opgegeven voor de balansrekening
+Crediteuren of Debiteuren, dan moet er voor dit bedrag
+ook openstaande posten worden ingevoerd met een of
+meer adm_relatie opdrachten.
+
   adm_relatie <boekstuk> <datum> <code> <omschrijving> <bedrag>
-		Invoeren van een openstaande post uit het voorgaande
-		boekjaar. Het <boekstuk> moet volledig zijn, dus
-		<dagboek>:<boekjaar>:<nummer>.
+
+Invoeren van een openstaande post uit het voorgaande
+boekjaar. Het <boekstuk> moet volledig zijn, dus
+<dagboek>:<boekjaar>:<nummer>.
+
   adm_open
-		Alle informatie die met de bovenstaande opdrachten is
-		ingevoerd, wordt verwerkt.
+
+Alle informatie die met de bovenstaande opdrachten is
+ingevoerd, wordt verwerkt.
 EOS
 }
 
